==> metricflow-0.200.0.dev15.tar.gz: metricflow-0.200.0.dev15/metricflow/test/snapshots/test_metric_time_dimension_to_sql.py/SqlQueryPlan/BigQuery/test_simple_query_with_metric_time_dimension__plan0.sql <==
-- Combine Metrics
SELECT
  COALESCE(subq_4.metric_time, subq_9.metric_time) AS metric_time
  , MAX(subq_4.bookings) AS bookings
  , MAX(subq_9.booking_payments) AS booking_payments
FROM (
  -- Compute Metrics via Expressions
  SELECT
    subq_3.metric_time
    , subq_3.bookings
  FROM (
    -- Aggregate Measures
    SELECT
      subq_2.metric_time
      , SUM(subq_2.bookings) AS bookings
    FROM (
      -- Pass Only Elements:
      --   ['bookings', 'metric_time']
      SELECT
        subq_1.metric_time
        , subq_1.bookings
      FROM (
        -- Metric Time Dimension 'ds'
        SELECT
          subq_0.ds
          , subq_0.ds__week
          , subq_0.ds__month
          , subq_0.ds__quarter
          , subq_0.ds__year
          , subq_0.ds_partitioned
          , subq_0.ds_partitioned__week
          , subq_0.ds_partitioned__month
          , subq_0.ds_partitioned__quarter
          , subq_0.ds_partitioned__year
          , subq_0.paid_at
          , subq_0.paid_at__week
          , subq_0.paid_at__month
          , subq_0.paid_at__quarter
          , subq_0.paid_at__year
          , subq_0.booking__ds
          , subq_0.booking__ds__week
          , subq_0.booking__ds__month
          , subq_0.booking__ds__quarter
          , subq_0.booking__ds__year
          , subq_0.booking__ds_partitioned
          , subq_0.booking__ds_partitioned__week
          , subq_0.booking__ds_partitioned__month
          , subq_0.booking__ds_partitioned__quarter
          , subq_0.booking__ds_partitioned__year
          , subq_0.booking__paid_at
          , subq_0.booking__paid_at__week
          , subq_0.booking__paid_at__month
          , subq_0.booking__paid_at__quarter
          , subq_0.booking__paid_at__year
          , subq_0.ds AS metric_time
          , subq_0.ds__week AS metric_time__week
          , subq_0.ds__month AS metric_time__month
          , subq_0.ds__quarter AS metric_time__quarter
          , subq_0.ds__year AS metric_time__year
          , subq_0.listing
          , subq_0.guest
          , subq_0.host
          , subq_0.booking__listing
          , subq_0.booking__guest
          , subq_0.booking__host
          , subq_0.is_instant
          , subq_0.booking__is_instant
          , subq_0.bookings
          , subq_0.instant_bookings
          , subq_0.booking_value
          , subq_0.max_booking_value
          , subq_0.min_booking_value
          , subq_0.bookers
          , subq_0.average_booking_value
          , subq_0.referred_bookings
          , subq_0.median_booking_value
          , subq_0.booking_value_p99
          , subq_0.discrete_booking_value_p99
          , subq_0.approximate_continuous_booking_value_p99
          , subq_0.approximate_discrete_booking_value_p99
        FROM (
          -- Read Elements From Semantic Model 'bookings_source'
          SELECT
            1 AS bookings
            , CASE WHEN is_instant THEN 1 ELSE 0 END AS instant_bookings
            , bookings_source_src_10001.booking_value
            , bookings_source_src_10001.booking_value AS max_booking_value
            , bookings_source_src_10001.booking_value AS min_booking_value
            , bookings_source_src_10001.guest_id AS bookers
            , bookings_source_src_10001.booking_value AS average_booking_value
            , bookings_source_src_10001.booking_value AS booking_payments
            , CASE WHEN referrer_id IS NOT NULL THEN 1 ELSE 0 END AS referred_bookings
            , bookings_source_src_10001.booking_value AS median_booking_value
            , bookings_source_src_10001.booking_value AS booking_value_p99
            , bookings_source_src_10001.booking_value AS discrete_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_continuous_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_discrete_booking_value_p99
            , bookings_source_src_10001.is_instant
            , bookings_source_src_10001.ds
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, isoyear) AS ds__year
            , bookings_source_src_10001.ds_partitioned
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoyear) AS ds_partitioned__year
            , bookings_source_src_10001.paid_at
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoyear) AS paid_at__year
            , bookings_source_src_10001.is_instant AS booking__is_instant
            , bookings_source_src_10001.ds AS booking__ds
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS booking__ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS booking__ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS booking__ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, isoyear) AS booking__ds__year
            , bookings_source_src_10001.ds_partitioned AS booking__ds_partitioned
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS booking__ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS booking__ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS booking__ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoyear) AS booking__ds_partitioned__year
            , bookings_source_src_10001.paid_at AS booking__paid_at
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS booking__paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS booking__paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS booking__paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoyear) AS booking__paid_at__year
            , bookings_source_src_10001.listing_id AS listing
            , bookings_source_src_10001.guest_id AS guest
            , bookings_source_src_10001.host_id AS host
            , bookings_source_src_10001.listing_id AS booking__listing
            , bookings_source_src_10001.guest_id AS booking__guest
            , bookings_source_src_10001.host_id AS booking__host
          FROM ***************************.fct_bookings bookings_source_src_10001
        ) subq_0
      ) subq_1
    ) subq_2
    GROUP BY
      metric_time
  ) subq_3
) subq_4
FULL OUTER JOIN (
  -- Compute Metrics via Expressions
  SELECT
    subq_8.metric_time
    , subq_8.booking_payments
  FROM (
    -- Aggregate Measures
    SELECT
      subq_7.metric_time
      , SUM(subq_7.booking_payments) AS booking_payments
    FROM (
      -- Pass Only Elements:
      --   ['booking_payments', 'metric_time']
      SELECT
        subq_6.metric_time
        , subq_6.booking_payments
      FROM (
        -- Metric Time Dimension 'paid_at'
        SELECT
          subq_5.ds
          , subq_5.ds__week
          , subq_5.ds__month
          , subq_5.ds__quarter
          , subq_5.ds__year
          , subq_5.ds_partitioned
          , subq_5.ds_partitioned__week
          , subq_5.ds_partitioned__month
          , subq_5.ds_partitioned__quarter
          , subq_5.ds_partitioned__year
          , subq_5.paid_at
          , subq_5.paid_at__week
          , subq_5.paid_at__month
          , subq_5.paid_at__quarter
          , subq_5.paid_at__year
          , subq_5.booking__ds
          , subq_5.booking__ds__week
          , subq_5.booking__ds__month
          , subq_5.booking__ds__quarter
          , subq_5.booking__ds__year
          , subq_5.booking__ds_partitioned
          , subq_5.booking__ds_partitioned__week
          , subq_5.booking__ds_partitioned__month
          , subq_5.booking__ds_partitioned__quarter
          , subq_5.booking__ds_partitioned__year
          , subq_5.booking__paid_at
          , subq_5.booking__paid_at__week
          , subq_5.booking__paid_at__month
          , subq_5.booking__paid_at__quarter
          , subq_5.booking__paid_at__year
          , subq_5.paid_at AS metric_time
          , subq_5.paid_at__week AS metric_time__week
          , subq_5.paid_at__month AS metric_time__month
          , subq_5.paid_at__quarter AS metric_time__quarter
          , subq_5.paid_at__year AS metric_time__year
          , subq_5.listing
          , subq_5.guest
          , subq_5.host
          , subq_5.booking__listing
          , subq_5.booking__guest
          , subq_5.booking__host
          , subq_5.is_instant
          , subq_5.booking__is_instant
          , subq_5.booking_payments
        FROM (
          -- Read Elements From Semantic Model 'bookings_source'
          SELECT
            1 AS bookings
            , CASE WHEN is_instant THEN 1 ELSE 0 END AS instant_bookings
            , bookings_source_src_10001.booking_value
            , bookings_source_src_10001.booking_value AS max_booking_value
            , bookings_source_src_10001.booking_value AS min_booking_value
            , bookings_source_src_10001.guest_id AS bookers
            , bookings_source_src_10001.booking_value AS average_booking_value
            , bookings_source_src_10001.booking_value AS booking_payments
            , CASE WHEN referrer_id IS NOT NULL THEN 1 ELSE 0 END AS referred_bookings
            , bookings_source_src_10001.booking_value AS median_booking_value
            , bookings_source_src_10001.booking_value AS booking_value_p99
            , bookings_source_src_10001.booking_value AS discrete_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_continuous_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_discrete_booking_value_p99
            , bookings_source_src_10001.is_instant
            , bookings_source_src_10001.ds
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, isoyear) AS ds__year
            , bookings_source_src_10001.ds_partitioned
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoyear) AS ds_partitioned__year
            , bookings_source_src_10001.paid_at
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoyear) AS paid_at__year
            , bookings_source_src_10001.is_instant AS booking__is_instant
            , bookings_source_src_10001.ds AS booking__ds
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS booking__ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS booking__ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS booking__ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, isoyear) AS booking__ds__year
            , bookings_source_src_10001.ds_partitioned AS booking__ds_partitioned
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS booking__ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS booking__ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS booking__ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoyear) AS booking__ds_partitioned__year
            , bookings_source_src_10001.paid_at AS booking__paid_at
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS booking__paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS booking__paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS booking__paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoyear) AS booking__paid_at__year
            , bookings_source_src_10001.listing_id AS listing
            , bookings_source_src_10001.guest_id AS guest
            , bookings_source_src_10001.host_id AS host
            , bookings_source_src_10001.listing_id AS booking__listing
            , bookings_source_src_10001.guest_id AS booking__guest
            , bookings_source_src_10001.host_id AS booking__host
          FROM ***************************.fct_bookings bookings_source_src_10001
        ) subq_5
      ) subq_6
    ) subq_7
    GROUP BY
      metric_time
  ) subq_8
) subq_9
ON
  subq_4.metric_time = subq_9.metric_time
GROUP BY
  metric_time

==> metricflow-0.202.0.tar.gz: metricflow-0.202.0/metricflow/test/snapshots/test_metric_time_dimension_to_sql.py/SqlQueryPlan/BigQuery/test_simple_query_with_metric_time_dimension__plan0.sql <==
-- Combine Metrics
SELECT
  COALESCE(subq_4.metric_time__day, subq_9.metric_time__day) AS metric_time__day
  , MAX(subq_4.bookings) AS bookings
  , MAX(subq_9.booking_payments) AS booking_payments
FROM (
  -- Compute Metrics via Expressions
  SELECT
    subq_3.metric_time__day
    , subq_3.bookings
  FROM (
    -- Aggregate Measures
    SELECT
      subq_2.metric_time__day
      , SUM(subq_2.bookings) AS bookings
    FROM (
      -- Pass Only Elements:
      --   ['bookings', 'metric_time__day']
      SELECT
        subq_1.metric_time__day
        , subq_1.bookings
      FROM (
        -- Metric Time Dimension 'ds'
        SELECT
          subq_0.ds__day
          , subq_0.ds__week
          , subq_0.ds__month
          , subq_0.ds__quarter
          , subq_0.ds__year
          , subq_0.ds_partitioned__day
          , subq_0.ds_partitioned__week
          , subq_0.ds_partitioned__month
          , subq_0.ds_partitioned__quarter
          , subq_0.ds_partitioned__year
          , subq_0.paid_at__day
          , subq_0.paid_at__week
          , subq_0.paid_at__month
          , subq_0.paid_at__quarter
          , subq_0.paid_at__year
          , subq_0.booking__ds__day
          , subq_0.booking__ds__week
          , subq_0.booking__ds__month
          , subq_0.booking__ds__quarter
          , subq_0.booking__ds__year
          , subq_0.booking__ds_partitioned__day
          , subq_0.booking__ds_partitioned__week
          , subq_0.booking__ds_partitioned__month
          , subq_0.booking__ds_partitioned__quarter
          , subq_0.booking__ds_partitioned__year
          , subq_0.booking__paid_at__day
          , subq_0.booking__paid_at__week
          , subq_0.booking__paid_at__month
          , subq_0.booking__paid_at__quarter
          , subq_0.booking__paid_at__year
          , subq_0.ds__day AS metric_time__day
          , subq_0.ds__week AS metric_time__week
          , subq_0.ds__month AS metric_time__month
          , subq_0.ds__quarter AS metric_time__quarter
          , subq_0.ds__year AS metric_time__year
          , subq_0.listing
          , subq_0.guest
          , subq_0.host
          , subq_0.booking__listing
          , subq_0.booking__guest
          , subq_0.booking__host
          , subq_0.is_instant
          , subq_0.booking__is_instant
          , subq_0.bookings
          , subq_0.instant_bookings
          , subq_0.booking_value
          , subq_0.max_booking_value
          , subq_0.min_booking_value
          , subq_0.bookers
          , subq_0.average_booking_value
          , subq_0.referred_bookings
          , subq_0.median_booking_value
          , subq_0.booking_value_p99
          , subq_0.discrete_booking_value_p99
          , subq_0.approximate_continuous_booking_value_p99
          , subq_0.approximate_discrete_booking_value_p99
        FROM (
          -- Read Elements From Semantic Model 'bookings_source'
          SELECT
            1 AS bookings
            , CASE WHEN is_instant THEN 1 ELSE 0 END AS instant_bookings
            , bookings_source_src_10001.booking_value
            , bookings_source_src_10001.booking_value AS max_booking_value
            , bookings_source_src_10001.booking_value AS min_booking_value
            , bookings_source_src_10001.guest_id AS bookers
            , bookings_source_src_10001.booking_value AS average_booking_value
            , bookings_source_src_10001.booking_value AS booking_payments
            , CASE WHEN referrer_id IS NOT NULL THEN 1 ELSE 0 END AS referred_bookings
            , bookings_source_src_10001.booking_value AS median_booking_value
            , bookings_source_src_10001.booking_value AS booking_value_p99
            , bookings_source_src_10001.booking_value AS discrete_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_continuous_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_discrete_booking_value_p99
            , bookings_source_src_10001.is_instant
            , bookings_source_src_10001.ds AS ds__day
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, year) AS ds__year
            , bookings_source_src_10001.ds_partitioned AS ds_partitioned__day
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, year) AS ds_partitioned__year
            , bookings_source_src_10001.paid_at AS paid_at__day
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, year) AS paid_at__year
            , bookings_source_src_10001.is_instant AS booking__is_instant
            , bookings_source_src_10001.ds AS booking__ds__day
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS booking__ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS booking__ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS booking__ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, year) AS booking__ds__year
            , bookings_source_src_10001.ds_partitioned AS booking__ds_partitioned__day
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS booking__ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS booking__ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS booking__ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, year) AS booking__ds_partitioned__year
            , bookings_source_src_10001.paid_at AS booking__paid_at__day
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS booking__paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS booking__paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS booking__paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, year) AS booking__paid_at__year
            , bookings_source_src_10001.listing_id AS listing
            , bookings_source_src_10001.guest_id AS guest
            , bookings_source_src_10001.host_id AS host
            , bookings_source_src_10001.listing_id AS booking__listing
            , bookings_source_src_10001.guest_id AS booking__guest
            , bookings_source_src_10001.host_id AS booking__host
          FROM ***************************.fct_bookings bookings_source_src_10001
        ) subq_0
      ) subq_1
    ) subq_2
    GROUP BY
      metric_time__day
  ) subq_3
) subq_4
FULL OUTER JOIN (
  -- Compute Metrics via Expressions
  SELECT
    subq_8.metric_time__day
    , subq_8.booking_payments
  FROM (
    -- Aggregate Measures
    SELECT
      subq_7.metric_time__day
      , SUM(subq_7.booking_payments) AS booking_payments
    FROM (
      -- Pass Only Elements:
      --   ['booking_payments', 'metric_time__day']
      SELECT
        subq_6.metric_time__day
        , subq_6.booking_payments
      FROM (
        -- Metric Time Dimension 'paid_at'
        SELECT
          subq_5.ds__day
          , subq_5.ds__week
          , subq_5.ds__month
          , subq_5.ds__quarter
          , subq_5.ds__year
          , subq_5.ds_partitioned__day
          , subq_5.ds_partitioned__week
          , subq_5.ds_partitioned__month
          , subq_5.ds_partitioned__quarter
          , subq_5.ds_partitioned__year
          , subq_5.paid_at__day
          , subq_5.paid_at__week
          , subq_5.paid_at__month
          , subq_5.paid_at__quarter
          , subq_5.paid_at__year
          , subq_5.booking__ds__day
          , subq_5.booking__ds__week
          , subq_5.booking__ds__month
          , subq_5.booking__ds__quarter
          , subq_5.booking__ds__year
          , subq_5.booking__ds_partitioned__day
          , subq_5.booking__ds_partitioned__week
          , subq_5.booking__ds_partitioned__month
          , subq_5.booking__ds_partitioned__quarter
          , subq_5.booking__ds_partitioned__year
          , subq_5.booking__paid_at__day
          , subq_5.booking__paid_at__week
          , subq_5.booking__paid_at__month
          , subq_5.booking__paid_at__quarter
          , subq_5.booking__paid_at__year
          , subq_5.paid_at__day AS metric_time__day
          , subq_5.paid_at__week AS metric_time__week
          , subq_5.paid_at__month AS metric_time__month
          , subq_5.paid_at__quarter AS metric_time__quarter
          , subq_5.paid_at__year AS metric_time__year
          , subq_5.listing
          , subq_5.guest
          , subq_5.host
          , subq_5.booking__listing
          , subq_5.booking__guest
          , subq_5.booking__host
          , subq_5.is_instant
          , subq_5.booking__is_instant
          , subq_5.booking_payments
        FROM (
          -- Read Elements From Semantic Model 'bookings_source'
          SELECT
            1 AS bookings
            , CASE WHEN is_instant THEN 1 ELSE 0 END AS instant_bookings
            , bookings_source_src_10001.booking_value
            , bookings_source_src_10001.booking_value AS max_booking_value
            , bookings_source_src_10001.booking_value AS min_booking_value
            , bookings_source_src_10001.guest_id AS bookers
            , bookings_source_src_10001.booking_value AS average_booking_value
            , bookings_source_src_10001.booking_value AS booking_payments
            , CASE WHEN referrer_id IS NOT NULL THEN 1 ELSE 0 END AS referred_bookings
            , bookings_source_src_10001.booking_value AS median_booking_value
            , bookings_source_src_10001.booking_value AS booking_value_p99
            , bookings_source_src_10001.booking_value AS discrete_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_continuous_booking_value_p99
            , bookings_source_src_10001.booking_value AS approximate_discrete_booking_value_p99
            , bookings_source_src_10001.is_instant
            , bookings_source_src_10001.ds AS ds__day
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, year) AS ds__year
            , bookings_source_src_10001.ds_partitioned AS ds_partitioned__day
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, year) AS ds_partitioned__year
            , bookings_source_src_10001.paid_at AS paid_at__day
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, year) AS paid_at__year
            , bookings_source_src_10001.is_instant AS booking__is_instant
            , bookings_source_src_10001.ds AS booking__ds__day
            , DATE_TRUNC(bookings_source_src_10001.ds, isoweek) AS booking__ds__week
            , DATE_TRUNC(bookings_source_src_10001.ds, month) AS booking__ds__month
            , DATE_TRUNC(bookings_source_src_10001.ds, quarter) AS booking__ds__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds, year) AS booking__ds__year
            , bookings_source_src_10001.ds_partitioned AS booking__ds_partitioned__day
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, isoweek) AS booking__ds_partitioned__week
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, month) AS booking__ds_partitioned__month
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, quarter) AS booking__ds_partitioned__quarter
            , DATE_TRUNC(bookings_source_src_10001.ds_partitioned, year) AS booking__ds_partitioned__year
            , bookings_source_src_10001.paid_at AS booking__paid_at__day
            , DATE_TRUNC(bookings_source_src_10001.paid_at, isoweek) AS booking__paid_at__week
            , DATE_TRUNC(bookings_source_src_10001.paid_at, month) AS booking__paid_at__month
            , DATE_TRUNC(bookings_source_src_10001.paid_at, quarter) AS booking__paid_at__quarter
            , DATE_TRUNC(bookings_source_src_10001.paid_at, year) AS booking__paid_at__year
            , bookings_source_src_10001.listing_id AS listing
            , bookings_source_src_10001.guest_id AS guest
            , bookings_source_src_10001.host_id AS host
            , bookings_source_src_10001.listing_id AS booking__listing
            , bookings_source_src_10001.guest_id AS booking__guest
            , bookings_source_src_10001.host_id AS booking__host
          FROM ***************************.fct_bookings bookings_source_src_10001
        ) subq_5
      ) subq_6
    ) subq_7
    GROUP BY
      metric_time__day
  ) subq_8
) subq_9
ON
  subq_4.metric_time__day = subq_9.metric_time__day
GROUP BY
  metric_time__day
